==> katana-0.8.5%2B11.tar.gz: lib/katana.dart <==
// Copyright 2021 mathru. All rights reserved.

/// This package contains utility classes such as the Masamune package.
///
/// To use, import `package:katana/katana.dart`.
///
/// [mathru.net]: https://mathru.net
/// [YouTube]: https://www.youtube.com/c/mathrunetchannel
library katana;

import 'dart:async';
import 'dart:convert';
import 'dart:math';

import 'package:crypto/crypto.dart';
import 'package:csv/csv.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:intl/date_symbol_data_local.dart';
import 'package:intl/intl.dart';
import 'package:riverpod/riverpod.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:sprintf/sprintf.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:uuid/uuid.dart';
import 'config/others/others.dart'
    if (dart.library.io) 'config/mobile/mobile.dart'
    if (dart.library.js) 'config/others/others.dart'
    if (dart.library.html) 'config/others/others.dart';

export 'package:sprintf/sprintf.dart';
export 'config/others/others.dart'
    if (dart.library.io) 'config/mobile/mobile.dart'
    if (dart.library.js) 'config/others/others.dart'
    if (dart.library.html) 'config/others/others.dart';

part "localize/localize.dart";
part "prefs/prefs.dart";
part "src/const.dart";
part "src/extensions.dart";
part "src/functions.dart";
part "src/typedef.dart";

part "provider/state.dart";
part "provider/focus_node.dart";
part "provider/text_editing_controller.dart";

==> katana-0.9.0%2B11.tar.gz: lib/katana.dart <==
// Copyright 2022 mathru. All rights reserved.

/// This package contains utility classes such as the Masamune package.
///
/// To use, import `package:katana/katana.dart`.
///
/// [mathru.net]: https://mathru.net
/// [YouTube]: https://www.youtube.com/c/mathrunetchannel
library katana;

import 'dart:async';
import 'dart:convert';
import 'dart:math';

import 'package:crypto/crypto.dart';
import 'package:csv/csv.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
// ignore: implementation_imports
import 'package:flutter_riverpod/src/framework.dart';
import 'package:intl/date_symbol_data_local.dart';
import 'package:intl/intl.dart';
import 'package:share_plus/share_plus.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:sprintf/sprintf.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:uuid/uuid.dart';

import 'config/others/others.dart'
    if (dart.library.io) 'config/mobile/mobile.dart'
    if (dart.library.js) 'config/others/others.dart'
    if (dart.library.html) 'config/others/others.dart';

export 'package:sprintf/sprintf.dart';

export 'config/others/others.dart'
    if (dart.library.io) 'config/mobile/mobile.dart'
    if (dart.library.js) 'config/others/others.dart'
    if (dart.library.html) 'config/others/others.dart';

part 'enum/ages.dart';
part 'enum/gender.dart';
part "localize/localize.dart";
part "prefs/prefs.dart";
part "provider/focus_node.dart";
part "provider/provider_scope_key.dart";
part "provider/state.dart";
part "provider/text_editing_controller.dart";
part "src/const.dart";
part "src/extensions.dart";
part "src/functions.dart";
part "src/typedef.dart";
